﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Data.OleDb;
using System.Configuration;
using System.Data;
using System.Web;
namespace Zxq.Data
{
    public class DataAccess
    {
        public OleDbConnection Conn = new OleDbConnection();
        public OleDbCommand Cmd = new OleDbCommand();
        public OleDbDataAdapter Da = new OleDbDataAdapter();
        public DataTable Dt = new DataTable();
        public DataSet Ds = new DataSet();

        #region 打开连接
        /// <summary>
        /// 打开连接
        /// </summary>        
        public void ConnOpen()
        {
            if (Conn.State.Equals(ConnectionState.Closed))
            {
                string DBPath = ConfigurationManager.AppSettings["ConnStr"];
                string StrConn = "Provider=Microsoft.Jet.OLEDB.4.0;Data source= " + System.Web.HttpContext.Current.Server.MapPath(DBPath);
                Conn = new OleDbConnection(StrConn);
                try
                {
                    Conn.Open();
                }
                catch (Exception e)
                {
                    throw new Exception(e.Message);
                }
            }
        }
        #endregion

        #region 关闭连接并释放
        /// <summary>
        /// 关闭连接并释放
        /// </summary>
        public void ConnClose()
        {
            if (Conn.State.Equals(ConnectionState.Open))
            {
                Conn.Close();
                //释放占用的资源
                Conn.Dispose();
            }
            else
            {
                Conn.Dispose();
            }
        }
        #endregion

        #region 执行CMD操作
        /// <summary>
        /// 执行CMD操作
        /// </summary>
        /// <param name="sql">sql语句</param>
        /// <returns>影响的记录数</returns>
        public int ExecuteCmd(string sql)
        {
            try
            {
                ConnOpen();
                //Cmd.Connection = Conn;
                //Cmd.CommandType = CommandType.Text;
                //Cmd.CommandText = sql;
                Cmd = new OleDbCommand(sql, Conn);
                return Cmd.ExecuteNonQuery();
            }
            catch (Exception e)
            {
                throw new Exception(e.Message, e);
            }
        }
        #endregion

        #region 返回首行首列
        /// <summary>
        /// 返回首行首列
        /// </summary>
        /// <param name="sql">sql语句</param>
        /// <returns></returns>
        public object ExecuteScalar(string sql)
        {
            try
            {
                ConnOpen();
                Cmd = new OleDbCommand(sql, Conn);
                object obj = Cmd.ExecuteScalar();
                if ((Object.Equals(obj, null)) || (Object.Equals(obj, System.DBNull.Value)))
                {
                    return null;
                }
                else
                {
                    return obj;
                }
            }
            catch (Exception e)
            {
                throw new Exception(e.Message, e);
            }
        }
        #endregion

        #region Insert数据
        /// <summary>
        /// Insert数据
        /// </summary>
        /// <param name="TableName">表名</param>
        /// <param name="ColumnName">字段</param>
        /// <param name="Values">值</param>
        /// <returns>影响的记录数</returns>
        public int Insert(string TableName, string[] ColumnName, string[] Values)
        {
            ConnOpen();
            StringBuilder SQL = new StringBuilder();
            SQL.Append("insert into ");					//insert into 
            SQL.Append("[" + TableName + "]");
            SQL.Append(" ([");
            int i;
            #region 字段
            for (i = 0; i < ColumnName.Length; i++)		//字段
            {
                if (Values[i] != null)
                {
                    SQL.Append(ColumnName[i]);
                    SQL.Append("],[");
                }
            }
            SQL = SQL.Remove(SQL.Length - 2, 2);
            #endregion
            SQL.Append(")  values ('");
            #region 值
            for (i = 0; i < ColumnName.Length; i++)     //字段对应的值
            {
                if (Values[i] != null)
                {
                    SQL.Append(Values[i]);
                    SQL.Append("','");
                }
            }
            SQL = SQL.Remove(SQL.Length - 2, 2);
            #endregion
            SQL.Append(") ");
            return ExecuteCmd(SQL.ToString());
        }
        #endregion

        #region Update数据
        /// <summary>
        /// Update数据
        /// </summary>
        /// <param name="TableName">表名</param>
        /// <param name="ColumnName">字段</param>
        /// <param name="Values">值</param>
        /// <param name="Filter">条件</param>
        /// <returns>影响的记录数</returns>
        public int Update(string TableName, string[] ColumnName, string[] Values, string Filter)
        {
            StringBuilder SQL = new StringBuilder();
            SQL.Append("update ");					//update
            SQL.Append("[" + TableName + "]");
            SQL.Append(" set ");
            int i;
            #region 字段 = 值
            for (i = 0; i < ColumnName.Length; i++)
            {
                if (Values[i] != null)
                {
                    SQL.Append("[");
                    SQL.Append(ColumnName[i]);					//update
                    SQL.Append("]='");
                    SQL.Append(Values[i]);
                    SQL.Append("',");
                }
            }
            SQL = SQL.Remove(SQL.Length - 1, 1);	//去掉最后一个 ","
            #endregion
            SQL.Append(" where ");
            SQL.Append(Filter);
            return ExecuteCmd(SQL.ToString());
        }
        #endregion

        #region UpdateHit数据
        /// <summary>
        /// 常用于计算器
        /// </summary>
        /// <param name="TableName">表名</param>
        /// <param name="ColumnName">字段</param>
        /// <param name="Values">值</param>
        /// <param name="Filter">条件</param>
        /// <returns>影响的记录数</returns>
        public int UpdateHit(string TableName, string ColumnName, string Values, string Filter)
        {
            ConnOpen();
            StringBuilder SQL = new StringBuilder();
            SQL.Append("update ");					//update
            SQL.Append("[" + TableName + "]");
            SQL.Append(" set ");
            SQL.Append("[" + ColumnName + "]");					//update
            SQL.Append("=");
            SQL.Append(Values);
            SQL.Append(" where ");
            SQL.Append(Filter);
            return ExecuteCmd(SQL.ToString());
        }
        #endregion

        #region 计算总数
        /// <summary>
        /// 计算总数
        /// </summary>
        /// <param name="TableName">表名</param>
        /// <param name="ColumnName">字段</param>
        /// <param name="Filter">条件</param>
        /// <returns>影响的记录数</returns>
        public int GetRecordCount(string TableName, string ColumnName, string Filter)
        {
            ConnOpen();
            StringBuilder SQL = new StringBuilder();
            SQL.Append("select ");
            SQL.Append("" + ColumnName + "");
            SQL.Append(" from ");
            SQL.Append("[" + TableName + "]");
            if (Filter != "") SQL.Append(" where " + Filter);
            object obj = ExecuteScalar(SQL.ToString());
            if (obj == null)
            {
                return -1;
            }
            else
            {
                return Convert.ToInt32(obj);
            }
        }
        #endregion

        #region Delete数据
        /// <summary>
        /// Delete数据
        /// </summary>
        /// <param name="TableName">表名</param>
        /// <param name="Filter">条件</param>
        /// <returns></returns>
        public int Delete(string TableName, string Filter)
        {
            ConnOpen();
            StringBuilder SQL = new StringBuilder();
            SQL.Append("delete from ");
            SQL.Append("[" + TableName + "]");
            SQL.Append(" where ");
            SQL.Append(Filter);
            return ExecuteCmd(SQL.ToString());
        }
        /// <summary>
        /// Delete数据
        /// </summary>
        /// <param name="TableName">表名</param>      
        /// <returns></returns>
        public int Delete(string TableName)
        {
            ConnOpen();
            StringBuilder SQL = new StringBuilder();
            SQL.Append("delete from ");
            SQL.Append("[" + TableName + "]");
            return ExecuteCmd(SQL.ToString());
        }
        #endregion

        #region select数据
        /// <summary>
        /// select数据
        /// </summary>
        /// <param name="TableName">表名</param>
        /// <param name="Num">显示条数 0代表所有,</param>
        /// <param name="ColumnName">字段</param>
        /// <param name="Filter">条件</param>
        /// <param name="Order">排序</param>
        /// <returns>返回DataTable</returns>
        public DataTable Select(string TableName, int Num, string[] ColumnName, string Filter, string Order)
        {
            try
            {
                ConnOpen();
                StringBuilder SQL = new StringBuilder();
                SQL.Append("select ");
                if (Num > 0) SQL.Append("top " + Num + " ");
                int i;
                for (i = 0; i < ColumnName.Length - 1; i++)		//字段
                {
                    SQL.Append(ColumnName[i]);
                    SQL.Append(",");
                }
                SQL.Append(ColumnName[i]);
                SQL.Append(" from ");
                SQL.Append("[" + TableName + "]");
                if (Filter != "") SQL.Append(" where " + Filter);
                if (Order != "") SQL.Append(" Order By " + Order);
                Da = new OleDbDataAdapter(SQL.ToString(), Conn);
                Da.Fill(Dt);
            }
            catch (Exception e)
            {
                throw new Exception(e.Message, e);
            }
            return Dt;
        }
        #endregion

        #region 数据分页
        /// <summary>
        /// 数据分页
        /// </summary>
        /// <param name="param"></param>
        /// <param name="RecordCount"></param>
        /// <returns></returns>
        public DataTable DataPager(string[] param, out int RecordCount)
        {
            ConnOpen();
            string TableName = param[0];
            string KeyField = param[1];
            string ColumnName = param[2];
            int PageSize = Convert.ToInt32(param[3]);
            int P = Convert.ToInt32(param[4]) + 1;
            string Filter = param[5];
            string Order = param[7];

            string sqlStr = "from [" + TableName + "] where 1=1";
            if (Filter != "") sqlStr += " and " + Filter;
            string orderStr = "";
            if (Order != "")
            {
                orderStr = " order by " + Order;
            }
            RecordCount = GetRecordCount("" + TableName + "", " count(*)", Filter);
            int pageCount = RecordCount % PageSize == 0 ? RecordCount / PageSize : RecordCount / PageSize + 1;
            P = P > pageCount ? pageCount : P;
            if (P > 1)
            {
                sqlStr = sqlStr + " and " + KeyField + " not in (select top " + PageSize * (P - 1) + " " + KeyField + " " + sqlStr + orderStr + ")";
            }
            sqlStr += orderStr;
            sqlStr = "select top " + PageSize.ToString() + " " + ColumnName + " " + sqlStr;
            Da = new OleDbDataAdapter(sqlStr, Conn);
            Da.Fill(Dt);
            return Dt;
        }

        #endregion
    }
}